Utility
=======

Classes
-------

.. currentmodule:: ansys.edb.core.utility

.. autosummary::
   :toctree: _autosummary

   heat_sink.HeatSink
   hfss_extent_info.HfssExtentInfo
   layer_map.LayerMap
   material_property_thermal_modifier_params.AdvancedQuadraticParams
   material_property_thermal_modifier_params.BasicQuadraticParams
   port_post_processing_prop.PortPostProcessingProp
   rlc.Rlc
   temperature_settings.TemperatureSettings
   transform.Transform
   transform3d.Transform3D
   value.Value
   edb_error_manager.EDBErrorSeverity
   edb_error_manager.EDBError
   edb_error_manager.get_error_messages


Enums
-----

.. autosummary::
   :toctree: _autosummary

   heat_sink.HeatSinkFinOrientation
   hfss_extent_info.HFSSExtentInfoType
   hfss_extent_info.OpenRegionType
   layer_map.LayerMapUniqueDirection
